@@ -1,4 +1,4 @@
-__version__ = '1.1.0'
+__version__ = '1.2.1'
 
 import logging
 
@@ -12,7 +12,9 @@ from pika.connection import URLParameters
 from pika.connection import SSLOptions
 from pika.credentials import PlainCredentials
 from pika.spec import BasicProperties
+from pika.delivery_mode import DeliveryMode
 
+from pika import adapters
 from pika.adapters import BaseConnection
 from pika.adapters import BlockingConnection
 from pika.adapters import SelectConnection
